@@ -1,4 +1,5 @@
 # coding:utf-8
+from __future__ import unicode_literals
 
 """
 Function decoration for pluggable backoff and retry
@@ -97,11 +98,20 @@ import operator
 import logging
 import random
 import time
+import sys
 
 
 # Use module-specific logger with a default null handler.
 logger = logging.getLogger(__name__)
-logger.addHandler(logging.NullHandler())
+
+if sys.version_info < (2, 7, 0):  # pragma: no cover
+    class NullHandler(logging.Handler):
+        def emit(self, record):
+            pass
+    logger.addHandler(NullHandler())
+else:
+    logger.addHandler(logging.NullHandler())  # pragma: no cover
+
 logger.setLevel(logging.ERROR)
 
 
@@ -154,7 +164,7 @@ def constant(interval):
 
 # Formats a function invocation as a unicode string for logging.
 def _invoc_repr(f, args, kwargs):
-    args_out = ", ".join(unicode(a) for a in args)
+    args_out = ", ".join("%s" % a for a in args)
     if args and kwargs:
         args_out += ", "
     if kwargs:
